### BT+MCU 做灯类产品

如果 BT+MCU 做灯类产品，如果不需要涂鸦公版遥控器控制，只需要关注 DP 点的数据处理即可；

如果需要涂鸦公版遥控器控制，需要参考下面的所有遥控器会用到的指令，分别在 MCU 端做解析实现：

```
➜  _build git:(master) sudo ./app_main
ttyUSB0  
...
P
# 利用 0xB6 指令 MCU 发送开启本地对码时间窗，10秒钟
[dbg]hal_uart_send                 :112 SEND RAW DATAS:              55 AA 00 B6 00 03 0A 00 00 C2  （MCU->BT） 
[dbg]app_uart_run                  :94 RECEIVE RAW DATA:             55 AA 00 B6 00 01 00 B6 (BT->MCU)
[dbg]auc_mesh_open_pair_window     :94 LOCAL PAIR REPONSE:success

# 遥控器本地开始对码 MCU+BT 做的灯
# 因为对码的本质，是遥控器将灯加入一个群组，因此对码成功时，MCU+BT 会收到 0xB4 指令，告知 MCU 自身群组发生变化
[dbg]app_uart_run                  :94 RECEIVE RAW DATA:             55 AA 00 B4 00 11 08 C2 E8 00 00 00 00 00 00 00 00 00 00 00 00 00 00 76 55 AA 00 B6 00 01 03 B9 (BT->MCU)
[dbg]auc_mesh_get_group_addr       :80 MESH GET GROUP ADDRESS: num=8, [c2e8,]
[dbg]auc_mesh_open_pair_window     :94 LOCAL PAIR REPONSE:paired

...

# 对码时间超时，BT 会用 0xB6 通知 MCU
[dbg]app_uart_run                  :94 RECEIVE RAW DATA:             55 AA 00 B6 00 01 02 B8  （BT->MCU）
[dbg]auc_mesh_open_pair_window     :94 LOCAL PAIR REPONSE:timeout

# 遥控器按 ON 按钮，发送标准 SIG MODEL: onoff model，BT 通过 0xBD 命令透传给 MCU：(只取cmd_params的第一字节，1 为 ON)
[dbg]app_uart_run                  :94 RECEIVE RAW DATA:             55 AA 00 BD 00 0A 05 E0 C2 E8 03 82 00 02 01 5C 39 （BT->MCU）
[dbg]auc_mesh_sig_model_receive    :121 SIG MODEL RECEIVE:src=1504, dst=49896, op_code=0382, is_ack=0, cmd_params_len=2, cmd_params=[01,5c,


# 遥控器按 OFF 按钮，发送标准 SIG MODEL: onoff model，BT 通过 0xBD 命令透传给 MCU：(只取cmd_params的第一字节，0 为 OFF)
[dbg]app_uart_run                  :94 RECEIVE RAW DATA:             55 AA 00 BD 00 0A 05 E0 C2 E8 03 82 00 02 00 5D 39 
[dbg]auc_mesh_sig_model_receive    :121 SIG MODEL RECEIVE:src=1504, dst=49896, op_code=0382, is_ack=0, cmd_params_len=2, cmd_params=[00,5d,

# 遥控器按（亮度+/-）按钮，发送标准 VENDOR MODEL: 亮度调节，BT 通过 0xBF 命令透传给 MCU：(只取cmd_params的后 2 字节，0x6666/0xFFFF 表示亮度百分比，大端)
[dbg]app_uart_run                  :94 RECEIVE RAW DATA:             55 AA 00 BF 00 0A 05 E0 C2 E8 00 04 83 02 66 66 AC 
[dbg]auc_mesh_vendor_model_receive :135 VENDOR MODEL RECEIVE:src=1504, dst=49896, is_ack=0, cmd_params_len=4, cmd_params=[83,02,66,66,

# 遥控器按（色温+）按钮，发送标准 SIG MODEL: 色温调节，BT 通过 0xBD 命令透传给 MCU：(只取cmd_params的前 2 字节，0x2120 表示色温值，小端）
[dbg]app_uart_run                  :94 RECEIVE RAW DATA:             55 AA 00 BD 00 0D 05 E0 C2 E8 65 82 00 05 20 21 00 00 5E E3 
[dbg]auc_mesh_sig_model_receive    :121 SIG MODEL RECEIVE:src=1504, dst=49896, op_code=6582, is_ack=0, cmd_params_len=5, cmd_params=[20,21,00,00,5e,

# 遥控器按（色温-）按钮，发送标准 SIG MODEL: 色温调节，BT 通过 0xBD 命令透传给 MCU：(只取cmd_params的前 4 字节，0x00003020 表示色温值，小端）
[dbg]app_uart_run                  :94 RECEIVE RAW DATA:             55 AA 00 BD 00 0D 05 E0 C2 E8 65 82 00 05 20 30 00 00 5F F3 
[dbg]auc_mesh_sig_model_receive    :121 SIG MODEL RECEIVE:src=1504, dst=49896, op_code=6582, is_ack=0, cmd_params_len=5, cmd_params=[20,30,00,00,5f,

# 遥控器按（情景晚安、阅读、电视、场景循环（遥控器内置了0x4000,0x5000,0x6000,0x7000四个场景ID，每次按动切换为下一个））按钮，BT 通过 DP 命令透传给 MCU：(2 字节，为情景 ID, 大端）
[dbg]app_uart_run                  :94 RECEIVE RAW DATA:             55 AA 00 06 00 06 06 00 00 02 00 00 13 
[dbg]auc_download                  :45 DOWNLOAD
[dbg]ble_download_data_cb          :86 dpid=6, type=0, len=2, data=00 00

[dbg]app_uart_run                  :94 RECEIVE RAW DATA:             55 AA 00 06 00 06 06 00 00 02 10 00 23 
[dbg]auc_download                  :45 DOWNLOAD
[dbg]ble_download_data_cb          :86 dpid=6, type=0, len=2, data=10 00

[dbg]app_uart_run                  :94 RECEIVE RAW DATA:             55 AA 00 06 00 06 06 00 00 02 20 00 33 
[dbg]auc_download                  :45 DOWNLOAD
[dbg]ble_download_data_cb          :86 dpid=6, type=0, len=2, data=20 00

[dbg]app_uart_run                  :94 RECEIVE RAW DATA:             55 AA 00 06 00 06 06 00 00 02 40 00 53 
[dbg]auc_download                  :45 DOWNLOAD
[dbg]ble_download_data_cb          :86 dpid=6, type=0, len=2, data=40 00

# 遥控器按（倒计时）按钮，BT 通过 DP 命令透传给 MCU：(4 字节，0-86400, 间距: 1, 倍数: 0, 单位: s， 大端）
[dbg]app_uart_run                  :94 RECEIVE RAW DATA:             55 AA 00 06 00 08 07 02 00 04 00 00 03 84 A1 
[dbg]auc_download                  :45 DOWNLOAD
[dbg]ble_download_data_cb          :86 dpid=7, type=2, len=4, data=00 00 03 84

```
